"""
@auteur: David ALBERTO (www.astrolabe-science.fr)
"""
#Ce programme calcule les dates des phases de la Lune au cours d'une anne, et affiche un calendrier

import ephem  # module d'phmrides astronomiques
import matplotlib.pyplot as plt
import datetime  # Gestion des dates
from matplotlib.markers import MarkerStyle  # style de marqueur demi-lune
import locale

locale.setlocale(locale.LC_ALL, 'fr_FR.UTF-8')  # dates en franais
annee=2025 # AU CHOIX DE L'UTILISATEUR
point = 60  # taille du symbole

#Dfinitions des fonction de recherche des phases, au cours d'un mois
def NouvelleLune(date_debut, date_fin):
    Date=date_debut
    while Date<date_fin:
        NL=ephem.next_new_moon(Date)#calcul de la prochaine date de la phase
        Date=ephem.localtime(NL)#conversion en temps local
        if Date<date_fin:
            Y=float(Date.strftime('%d'))#numro du jour
            ax=axs[N-1]
            ax.scatter(0, -Y, s=point, c='k')  # point noir
            ax.text(0.1, -Y, Date.strftime('%d %b'), va='center')

def PremierQuartier(date_debut, date_fin):
    Date=date_debut
    while Date<date_fin:
        PQ=ephem.next_first_quarter_moon(Date)#calcul de la prochaine date de la phase
        Date=ephem.localtime(PQ)#conversion en temps local
        if Date<date_fin:
            Y=float(Date.strftime('%d'))#numro du jour
            ax=axs[N-1]
            ax.scatter(0, -Y, s=point, c='black', edgecolor="black")
            ax.scatter(0, -Y, s=point, c='white', edgecolor="black", marker=MarkerStyle("o", fillstyle="right"))
            ax.text(0.1, -Y, Date.strftime('%d %b'), va='center')

def PleinLune(date_debut, date_fin):
    Date=date_debut
    while Date<date_fin:
        PL=ephem.next_full_moon(Date)#calcul de la prochaine date de la phase
        Date=ephem.localtime(PL)#conversion en temps local
        if Date<date_fin:
            Y=float(Date.strftime('%d'))#numro du jour
            ax=axs[N-1]
            ax.scatter(0,  -Y, s=point, c='w', edgecolor='k')#point blanc
            ax.text(0.1, -Y, Date.strftime('%d %b'), va='center')

def DernierQuartier(date_debut, date_fin):
    Date=date_debut
    while Date<date_fin:
        DQ=ephem.next_last_quarter_moon(Date)#calcul de la prochaine date de la phase
        Date=ephem.localtime(DQ)#conversion en temps local
        if Date<date_fin:
            Y=float(Date.strftime('%d'))#numro du jour
            ax=axs[N-1]
            ax.scatter(0, -Y, s=point, c='white', edgecolor="black")
            ax.scatter(0, -Y, s=point, c='black', edgecolor="black", marker=MarkerStyle("o", fillstyle="right"))
            ax.text(0.1, -Y, Date.strftime('%d %b'), va='center')

#Paramtres du graphique :
plt.rcParams["font.family"] = "Roboto"  # ou autre police installe
plt.rcParams["font.size"] = 10  #   adapter aux dimensions des axes

fig, axs=plt.subplots(nrows=2, ncols=6,
                      facecolor='lavender')#cration d'une figure et de 12 axes (1 par mois)

#Les graphes forment une grille de 2 lignes et 6 colonnes
#on peut modifier le nombre de grilles et colonnes, pourvu que le produit fasse 12.
axs=axs.flatten()#pour accder   chaque graphe par axs[N]
fig.set_size_inches(7, 6)#dimensions de la figure, en pouces
"""
En modifiant les dimensions de la figure, il faudra peut-tre ajuster :
- la taille de la police
- les limites des axes en x et en y
Et rciproquement.
"""
plt.suptitle("phmrides de la lune en %i"%(annee), fontsize=16, color='royalblue', fontweight='bold')

for N in range(1, 12+1):#N : numro du mois courant, de 1   12
    ax=axs[N-1]
    date_debut=datetime.datetime(annee, N, 1)
    ax.set_title(date_debut.strftime("%B"), fontsize=13)#nom complet du mois
    ax.set_xticks([])#suppression des graduations
    ax.set_yticks([])#suppression des graduations
    ax.set_ylim(-32, 0.5)#hauteur suffisante pour les listes de dates
    ax.set_xlim(-0.1, 0.5)#largeur suffisante pour le texte
    if N==12:
        date_fin=datetime.datetime(annee+1, 1, 1)
    else:
        date_fin=datetime.datetime(annee, N+1, 1)
    NouvelleLune(date_debut, date_fin)
    PremierQuartier(date_debut, date_fin)
    PleinLune(date_debut, date_fin)
    DernierQuartier(date_debut, date_fin)

plt.tight_layout()#rduit les marges
NomFichier="ephemeridesLune"+str(annee)
#Le nom de fichier se terminera par l'anne
fig.savefig(NomFichier+".png", dpi=200)#cration d'un fichier image PNG
fig.savefig(NomFichier+".pdf")#cration d'un fichier PDF
plt.show()
